@@ -15,8 +15,9 @@
 
 from six.moves.urllib import parse
 
+from oslo.utils import encodeutils
+
 from heatclient.openstack.common.apiclient import base
-from heatclient.openstack.common import strutils
 from heatclient.v1 import stacks
 
 DEFAULT_PAGE_SIZE = 20
@@ -57,7 +58,7 @@ class ResourceManager(stacks.StackChildManager):
         stack_id = self._resolve_stack_id(stack_id)
         url_str = '/stacks/%s/resources/%s' % (
                   parse.quote(stack_id, ''),
-                  parse.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(encodeutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('GET', url_str)
         return Resource(self, body['resource'])
 
@@ -70,7 +71,7 @@ class ResourceManager(stacks.StackChildManager):
         stack_id = self._resolve_stack_id(stack_id)
         url_str = '/stacks/%s/resources/%s/metadata' % (
                   parse.quote(stack_id, ''),
-                  parse.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(encodeutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('GET', url_str)
         return body['metadata']
 
@@ -83,7 +84,7 @@ class ResourceManager(stacks.StackChildManager):
         stack_id = self._resolve_stack_id(stack_id)
         url_str = '/stacks/%s/resources/%s/signal' % (
                   parse.quote(stack_id, ''),
-                  parse.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(encodeutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('POST', url_str, data=data)
         return body
 
@@ -92,6 +93,6 @@ class ResourceManager(stacks.StackChildManager):
         instead.
         """
         url_str = '/resource_types/%s/template' % (
-                  parse.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(encodeutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('GET', url_str)
         return body
